@@ -12,7 +12,7 @@ from typing import List
 from multiprocessing.pool import ThreadPool
 from azure.core.exceptions import ResourceExistsError, ResourceNotFoundError
 
-from common import TaskResult, TaskMetadata, chunks
+from .common import TaskResult, TaskMetadata, chunks
 
 enough_workers_message = "There are already enough active workers"
 workers_long_running = "Workers are active for too long. Going to process as well."
